==> cell_tracking_bc-2021.11-py3-none-any.whl: cell_tracking_BC/task/tracking/main.py <==
# Copyright CNRS/Inria/UCA
# Contributor(s): Eric Debreuve (since 2021)
#
# eric.debreuve@cnrs.fr
#
# This software is governed by the CeCILL  license under French law and
# abiding by the rules of distribution of free software.  You can  use,
# modify and/ or redistribute the software under the terms of the CeCILL
# license as circulated by CEA, CNRS and INRIA at the following URL
# "http://www.cecill.info".
#
# As a counterpart to the access to the source code and  rights to copy,
# modify and redistribute granted by the license, users are provided only
# with a limited warranty  and the software's author,  the holder of the
# economic rights,  and the successive licensors  have only  limited
# liability.
#
# In this respect, the user's attention is drawn to the risks associated
# with loading,  using,  modifying and/or developing or reproducing the
# software by the user in light of its specific status of free software,
# that may mean  that it is complicated to manipulate,  and  that  also
# therefore means  that it is reserved for developers  and  experienced
# professionals having in-depth computer knowledge. Users are therefore
# encouraged to load and test the software's suitability as regards their
# requirements in conditions enabling the security of their systems and/or
# data to be ensured and,  more generally, to use and operate it in the
# same conditions as regards security.
#
# The fact that you are presently reading this means that you have had
# knowledge of the CeCILL license and that you accept its terms.

from typing import Iterator, Sequence

import numpy as nmpy

from cell_tracking_BC.task.tracking.generic import context_t
from cell_tracking_BC.type.cell import cell_t
from cell_tracking_BC.type.tracks import tracks_t


array_t = nmpy.ndarray


def CellsTracks(
    cells_per_time_point: Iterator[Sequence[cell_t]],
    context: context_t,
) -> tracks_t:
    """"""
    output = tracks_t()

    for t_idx, next_cells in enumerate(cells_per_time_point):
        if next_cells.__len__() == 0:
            raise ValueError(f"No cells at time point {t_idx}")

        context.DiscoverNextCells(next_cells)

        if t_idx > 0:
            for next_c_idx, next_cell in enumerate(next_cells):
                cell = context.PredecessorOfCell(next_cell, next_c_idx)
                if cell is not None:
                    output.AddTrackSegment(cell, next_cell, t_idx - 1)

        context.Advance()

    return output

==> cell_tracking_bc-2021.16-py3-none-any.whl: cell_tracking_BC/task/tracking/main.py <==
# Copyright CNRS/Inria/UCA
# Contributor(s): Eric Debreuve (since 2021)
#
# eric.debreuve@cnrs.fr
#
# This software is governed by the CeCILL  license under French law and
# abiding by the rules of distribution of free software.  You can  use,
# modify and/ or redistribute the software under the terms of the CeCILL
# license as circulated by CEA, CNRS and INRIA at the following URL
# "http://www.cecill.info".
#
# As a counterpart to the access to the source code and  rights to copy,
# modify and redistribute granted by the license, users are provided only
# with a limited warranty  and the software's author,  the holder of the
# economic rights,  and the successive licensors  have only  limited
# liability.
#
# In this respect, the user's attention is drawn to the risks associated
# with loading,  using,  modifying and/or developing or reproducing the
# software by the user in light of its specific status of free software,
# that may mean  that it is complicated to manipulate,  and  that  also
# therefore means  that it is reserved for developers  and  experienced
# professionals having in-depth computer knowledge. Users are therefore
# encouraged to load and test the software's suitability as regards their
# requirements in conditions enabling the security of their systems and/or
# data to be ensured and,  more generally, to use and operate it in the
# same conditions as regards security.
#
# The fact that you are presently reading this means that you have had
# knowledge of the CeCILL license and that you accept its terms.

from typing import Iterator, Sequence

import numpy as nmpy

from cell_tracking_BC.task.tracking.generic import context_t
from cell_tracking_BC.type.cell import cell_t
from cell_tracking_BC.type.tracks import unstructured_tracks_t


array_t = nmpy.ndarray


def CellsTracks(
    cells_per_time_point: Iterator[Sequence[cell_t]],
    context: context_t,
) -> unstructured_tracks_t:
    """"""
    output = unstructured_tracks_t()

    for t_idx, next_cells in enumerate(cells_per_time_point):
        if next_cells.__len__() == 0:
            raise ValueError(f"No cells at time point {t_idx}")

        context.DiscoverNextCells(next_cells)

        if t_idx > 0:
            for next_c_idx, next_cell in enumerate(next_cells):
                cell = context.PredecessorOfCell(next_cell, next_c_idx)
                if cell is not None:
                    output.AddTrackSegment(cell, next_cell, t_idx - 1)

        context.Advance()

    return output
